ig.degree.betweenness-package: ig.degree.betweenness: "Node+Edge Betweenness Community...

ig.degree.betweenness-packageR Documentation

ig.degree.betweenness: "Node+Edge Betweenness Community Detection Algorithm for 'igraph' Objects"

Description

Implements the "Node + Edge Betweenness" community detection algorithm for network analysis using 'igraph' objects. This algorithm combines node degree and betweenness centrality measures to identify communities within networks, with a gradient evident in social partitioning. The package provides functions for implementation of the algorithm, visualization, and analysis of the resulting community structure along with the original dataset used in the publication. Methods are based on results from Smith, Pittman and Xu (2026) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1002/cjs.70060")}.

Author(s)

Maintainer: Benjamin Smith benyamin.smith@mail.utoronto.ca (ORCID)

Authors:

See Also

Useful links:


ig.degree.betweenness documentation built on June 18, 2026, 1:06 a.m.