| ig.degree.betweenness-package | R Documentation |
Implements the "Node + Edge Betweenness" community detection algorithm for network analysis using 'igraph' objects. This algorithm combines node degree and betweenness centrality measures to identify communities within networks, with a gradient evident in social partitioning. The package provides functions for implementation of the algorithm, visualization, and analysis of the resulting community structure along with the original dataset used in the publication. Methods are based on results from Smith, Pittman and Xu (2026) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1002/cjs.70060")}.
Maintainer: Benjamin Smith benyamin.smith@mail.utoronto.ca (ORCID)
Authors:
Tyler Pittman Tyler.Pittman@uhn.ca (ORCID)
Wei Xu Wei.Xu@uhn.ca (ORCID)
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.